class PagesGenerator < Rails::Generators::Base
  source_root File.expand_path('../templates', __FILE__)

  def create_models
    generate :model, 'page name:string content:text page_title:string meta_keywords:text meta_description:text'
    rake 'db:migrate'
    remove_file 'app/models/page.rb' if File.exists?('app/models/page.rb')
    copy_file 'page.rb', 'app/models/page.rb'
  end

  def seed_data
    append_file 'db/seeds.rb', "Page.create! :name => 'index', :content => 'i am index. i have no data.'"
    rake 'db:seed'
  end

  def gems
    gem 'haml', '2.2.24'
    gem 'jquery-rails'
  
    gsub_file "Gemfile", /#.*\n/, "\n"
    gsub_file "Gemfile", /\n+/, "\n"
  end
  
  def jquery_setup
    generate 'jquery:install --ui'
  end

  def remove_files
    remove_file 'public/index.html' if File.exists?('public/index.html')
    remove_file 'app/views/layouts/application.html.erb' if File.exists?('app/views/layouts/application.html.erb')
    remove_file 'public/images/rails.png' if File.exists?('public/images/rails.png')
  end

  def add_routes
    route "root :to => 'page#show#index', :page => 'index'"
    route "match ':page/' => 'page#show#:page', :as => :link"
    route "resources :pages, :module => 'admin'"
    route "resources :messages, :module => 'admin'"
  end

  def copy_files
    copy_file 'admin_pages_controller.rb', 'app/controllers/admin/pages_controller.rb'
    copy_file 'application_controller.rb', 'app/controllers/application_controller.rb'
    copy_file 'dashboard_controller.rb', 'app/controllers/dashboard_controller.rb'
    copy_file 'page_controller.rb', 'app/controllers/page_controller.rb'
    copy_file 'page_helper.rb', 'app/helpers/page_helper.rb'
    copy_file 'index.html.haml', 'app/views/page/index.html.haml'
    copy_file 'page.html.haml', 'app/views/layouts/page.html.haml'
    copy_file 'application.html.haml', 'app/views/layouts/application.html.haml'
    copy_file 'style.sass', 'public/stylesheets/sass/style.sass'
    copy_file 'reset.sass', 'public/stylesheets/sass/reset.sass'
    copy_file 'admin.sass', 'public/stylesheets/sass/admin.sass'
    copy_file 'show.html.haml', 'app/views/page/show.html.haml'
    copy_file '_page.html.haml', 'app/views/page/_page.html.haml'
    copy_file '_header.html.haml', 'app/views/page/_header.html.haml'
    copy_file '_navigation.html.haml', 'app/views/page/_navigation.html.haml'
    copy_file '_sidebar.html.haml', 'app/views/page/_sidebar.html.haml'
    copy_file '_footer.html.haml', 'app/views/page/_footer.html.haml'  
    copy_file 'edit.html.erb', 'app/views/admin/pages/edit.html.erb'
    copy_file 'pages_index.html.haml', 'app/views/admin/pages/index.html.haml'
    copy_file 'new.html.erb', 'app/views/admin/pages/new.html.erb'
    copy_file 'show.html.erb', 'app/views/admin/pages/show.html.erb'
    copy_file '_admin_nav.html.haml', 'app/views/layouts/_admin_nav.html.haml'
    copy_file '_form.html.erb', 'app/views/admin/pages/_form.html.erb'
  end

  def blast_off
    run 'touch tmp/restart.txt'
  end
end